# Acquifer-Python-API

Python package providing utilitary functionalities when working with an ACQUIFER Imaging Machine.  
Functionalities include :  
- metadata persing from filenames  
- control of the microscope (tcpip) 

Similar functions are available for java programs (e.g Fiji) via the acquifer-core package, distributed via the ACQUIFER update site (upon request).  

## Installation
In a command prompt, use `pip install acquifer`.

The package can be installed locally for test purpose, by opening a command line in the repository directory : 
`pip install -e .` with e for "experimental"  
This way any change to the code is directly reflected. 